@@ -12,13 +12,14 @@ class Docker():
       print("[+] pull image.")
       client = docker.from_env()
       client.images.pull(image)
-      noneRemoveCommands = 'docker rmi -f $(sudo docker images ainblockchain/ain-worker-staging | grep "<none>" | awk "{print $3}")'
+      noneRemoveCommands = 'docker rmi $(docker images -f "dangling=true" -q)'
       Popen(noneRemoveCommands.split(" "), shell=False, stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
 
-      if gpu:
+      if gpu.lower() == "true":
         runtime = "nvidia"
       else:
         runtime = None
+
       print("[+] create container.")
       client.containers.run(
         image=image,
